
/*****************************************************************************
 *                                                                           *
 * This FILE mx12p_ui.h                                                      *
 * is part of the MX12P control panel program.  It is copyright (C) 1999 and *
 * 2000 by Gregory L. Kreider.  All rights reserved.  See the text in        *
 * mx12p_ui.c for distribution terms.                                        *
 *                                                                           *
 * The code in this file contains the header comments used to compile        *
 * mx12p_ui.c.  More comments can be found in mx12p_ui.doc.                  *
 *                                                                           *
 *****************************************************************************/



#ifndef CCA_H
#define CCA_H    1

#define _MX12P_UI_VERSION   1.0

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <ctype.h>

/* ++swig+ */

typedef struct {
  /* camera setup */
  int MX_Used;                      /* track whether device is in use */
  int MX_CommPort;                  /* requesed comm port */
  int MX_OpenPort;                  /* actual comm port being used */
  /* camera interface to world */
  int MX_BlackEnable;               /* enable black level shifting */
  int MX_BlackFine;                 /* set fine black level control */
  int MX_BlackValue;                /* black level offset */
  int MX_Gain;                      /* gain of on-board amp */
  int MX_Tint;                      /* integration time */
  int MX_Gamma;                     /* gamma correction enabled */
  int MX_Mirror;                    /* left/right mirrored read-out enabled */
  int MX_Standard;                  /* 50 or 60 Hz */
  int MX_Interlaced;                /* interlace enabled */
  int MX_Mode;                      /* camera triggering */
  int MX_Sync;                      /* composite sync in output enabled */
  int MX_Interface;                 /* TTL or differential */
  int MX_Option1;                   /* option 1 enabled */
  int MX_Option2;                   /* option 2 enabled */
  int MX_QPixelClock;               /* read back from PSU */
  int MX_QSensorType;               /* read back from PSU */
} mx12p_globals;


extern mx12p_globals mx12p_vars;
extern char* mx12p_fname;


extern int setup_mx12p(void);
extern int closedown_mx12p(void);
extern mx12p_globals* link_mx12p_vars(void);

extern int closeMX12P(void);
extern int openMX12P(void);
extern int transferToMX12P(void);
extern int attentionMX12P(void);
extern int readFromPSU(void);
extern int writeToPSU(void);
extern int readFromFile(void);
extern int writeToFile(void);

/* ++swig- */

extern int parseRCFile(FILE*);
extern int writeRCFile(FILE*);
extern void copyVarToPar(void);
extern void copyParToVar(void);

#endif /* CCA_H */
